unit usbDrDaqApi;
interface

uses PicoStatus;

{
From usbDrDaqApi.h to Pascal converted by Marin Hubinsk.
Get actual version from:
https://www.elso.sk/drdaq/usbDrDaqApi.pas
https://www.elso.sk/drdaq/PicoStatus.pas

Copyright  Marin Hubinsk 2020
v0.9 - 2020.03

This software is licensed under the European Union Public License (EUPL) v 1.2
The license is available in the 22 official languages of the EU. The English version is included here.
Please see https://joinup.ec.europa.eu/community/eupl/og_page/eupl for official translations of the other languages.



If you get problems with library 'libusbdrdaq.so.2' under linux, try to create symlink in folder where is your program compiled, pointing to /opt/picoscope/lib/libusbdrdaq.so.2.0.0
Execute this command in your binary output folder: ln -s /opt/picoscope/lib/libusbdrdaq.so.2.0.0 libusbdrdaq.so.2
From Lazarus project options: Compiler Options -> Compilation and Linking
Enable setting: "Pass options to linker with "-k", delimiter is space" with: -R ./
}

{$PACKRECORDS C}

{
  *************************************************************************
  *
  * Filename:    usbDrDaqApi.h
  * Author:      RPM & MAS
  * Description:
  *
  * This header defines the interface to driver routines for the
  * USB DrDAQ Data Logger.
  *
  * Copyright  2010-2018 Pico Technology Ltd. All rights reserved.
  *
  ************************************************************************
}


const
     {$IFDEF UNIX}
       libusbdrdaq = 'libusbdrdaq.so.2';
     {$ENDIF}

     {$ifdef WINDOWS}
        libusbdrdaq = 'USBDrDAQ.dll';
     {$endif}

type
  PICO_STATUS = int32;

    enUsbDrDaqInputs = (USB_DRDAQ_CHANNEL_EXT1 := 1,
                        USB_DRDAQ_CHANNEL_EXT2,
                        USB_DRDAQ_CHANNEL_EXT3,USB_DRDAQ_CHANNEL_SCOPE,
                        USB_DRDAQ_CHANNEL_PH,USB_DRDAQ_CHANNEL_RES,
                        USB_DRDAQ_CHANNEL_LIGHT,USB_DRDAQ_CHANNEL_TEMP,
                        USB_DRDAQ_CHANNEL_MIC_WAVE,USB_DRDAQ_CHANNEL_MIC_LEVEL,
                        USB_DRDAQ_MAX_CHANNELS := USB_DRDAQ_CHANNEL_MIC_LEVEL);

    USB_DRDAQ_INPUTS = enUsbDrDaqInputs;

    enUsbDrDaqScopeRange = (USB_DRDAQ_1V25,
                            USB_DRDAQ_2V5,
                            USB_DRDAQ_5V,
                            USB_DRDAQ_10V);

    USB_DRDAQ_SCOPE_RANGE = enUsbDrDaqScopeRange;

    enUsbDrDaqWave = (USB_DRDAQ_SINE,
                      USB_DRDAQ_SQUARE,
                      USB_DRDAQ_TRIANGLE,
                      USB_DRDAQ_RAMP_UP,
                      USB_DRDAQ_RAMP_DOWN,
                      USB_DRDAQ_DC);

    USB_DRDAQ_WAVE = enUsbDrDaqWave;

    enUsbDrDaqDO = (USB_DRDAQ_GPIO_1 := 1,
                    USB_DRDAQ_GPIO_2,
                    USB_DRDAQ_GPIO_3,
                    USB_DRDAQ_GPIO_4);

    USB_DRDAQ_GPIO = enUsbDrDaqDO;

    enUSBDrDAQInfo = (USBDrDAQ_DRIVER_VERSION,
                      USBDrDAQ_USB_VERSION,
                      USBDrDAQ_HARDWARE_VERSION,USBDrDAQ_VARIANT_INFO,
                      USBDrDAQ_BATCH_AND_SERIAL,USBDrDAQ_CAL_DATE,
                      USBDrDAQ_KERNEL_DRIVER_VERSION,USBDrDAQ_ERROR,
                      USBDrDAQ_SETTINGS,USBDrDAQ_FIRMWARE_VERSION,
                      USBDrDAQ_DRIVER_PATH := 14);

    USBDrDAQ_INFO = enUSBDrDAQInfo;

  type
    _BLOCK_METHOD = (BM_SINGLE,BM_WINDOW,BM_STREAM);
    BLOCK_METHOD = _BLOCK_METHOD;



Function UsbDrDaqOpenUnit(var handle : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqCloseUnit(handle : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetUnitInfo(
         handle : int16;
         buffer : pchar;
	 stringLength : int16;
	 var requiredSize : int16;
         info : PICO_INFO):PICO_STATUS; stdcall; external libusbdrdaq;

Function UsbDrDaqRun(
         handle : int16;
         no_of_values : int32;
         method : BLOCK_METHOD):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqReady(
         handle : int16;
         var ready : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqStop(handle : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetInterval(
         handle : int16;
         var us_for_block : int32;
         ideal_no_of_samples : int32;
         var channels : USB_DRDAQ_INPUTS;
         no_of_channels : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetIntervalF(
         handle : int16;
         var us_for_block : single;
         ideal_no_of_samples : int32;
         var channels : USB_DRDAQ_INPUTS;
         no_of_channels : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetTrigger(
         handle : int16;
         enabled : word;
         auto_trigger : word;
         auto_ms : word;
         channel : word;
         dir : word;
         threshold : int16;
         hysteresis : word;
         delay : single):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetValues(
         handle : int16;
         var values : int16;
         var noOfValues : cardinal;
         var overflow : word;
         var triggerIndex : cardinal):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetValuesF(
         handle : int16;
         var values : single;
         var noOfValues : cardinal;
         var overflow : word;
         var triggerIndex : cardinal):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetTriggerTimeOffsetNs(
         handle : int16;
         var time : int64):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetSingle(
         handle : int16;
         channel : USB_DRDAQ_INPUTS;
         var value : int16;
         var overflow : word):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetSingleF(
         handle : int16;
         channel : USB_DRDAQ_INPUTS;
         var value : single;
         var overflow : word):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqOpenUnitAsync(var status : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqOpenUnitProgress(
         var handle : int16;
         var progress : int16;
         var complete : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetScalings(
         handle : int16;
         channel : USB_DRDAQ_INPUTS;
         var nScales : int16;
         var currentScale : int16;
         names : pchar;
         namesSize : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetScalings(
         handle : int16;
         channel : USB_DRDAQ_INPUTS;
         scallingNumber : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetSigGenBuiltIn(
         handle : int16;
         offsetVoltage : int32;
         pkToPk : cardinal;
         frequency : int16;
         waveType : USB_DRDAQ_WAVE):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetSigGenArbitrary(
         handle : int16;
         offsetVoltage : int32;
         pkToPk : cardinal;
         var arbitraryWaveform : array of int16;
         arbitraryWaveformSize : int16;
         updateRate : int32):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqStopSigGen(handle : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetDO(
         handle : int16;
         IOChannel : USB_DRDAQ_GPIO;
         value : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetPWM(
         handle : int16;
         IOChannel : USB_DRDAQ_GPIO;
         period : int16;
         cycle : byte):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetInput(
         handle : int16;
	 IOChannel : USB_DRDAQ_GPIO;
         pullUp : int16;
         var value : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqStartPulseCount(
         handle : int16;
         IOChannel : USB_DRDAQ_GPIO;
         direction : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetPulseCount(
         handle : int16;
         IOChannel : USB_DRDAQ_GPIO;
         var count : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqEnableRGBLED(
         handle : int16;
         enabled : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetRGBLED(
         handle : int16;
         red : word;
         green : word;
         blue : word):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqGetChannelInfo(
         handle : int16;
         var min : single;
         var max : single;
         var places : int16;
         var divider : int16;
         channel : USB_DRDAQ_INPUTS):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqPingUnit(handle : int16):PICO_STATUS; stdcall; external libusbdrdaq;


Function UsbDrDaqSetRGBLED(
         handle : int16;
         enabled : word):PICO_STATUS; stdcall; external libusbdrdaq;


implementation


end.
